@@ -8,7 +8,7 @@ setMethod("Arith", signature(e1="SpatExtent", e2="numeric"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "%%") {
-			e1@ptr <- e1@ptr$align(e2[1], "")
+			e1@pnt <- e1@pnt$align(e2[1], "")
 		} else if (oper == "+") {
 			e2 <- rep_len(e2, 4)
 			e2[c(1,3)] <- -e2[c(1,3)]
@@ -80,10 +80,10 @@ setMethod("Arith", signature(e1="SpatExtent", e2="SpatExtent"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "+") {
-			e1@ptr <- e1@ptr$deepcopy()
-			e1@ptr$union(e2@ptr)
+			e1@pnt <- e1@pnt$deepcopy()
+			e1@pnt$union(e2@pnt)
 		} else if (oper == "*") {
-			e1@ptr <- e1@ptr$intersect(e2@ptr)
+			e1@pnt <- e1@pnt$intersect(e2@pnt)
 		} else if (oper == "/") {
 			d <- c(diff(e1[1:2]) / diff(e2[1:2]), diff(e1[3:4]) / diff(e2[3:4]))
 			names(d) <- c("x", "y")
@@ -104,11 +104,11 @@ setMethod("Arith", signature(e1="SpatVector", e2="SpatVector"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		if (oper == "+") {
-			e1@ptr <- e1@ptr$union(e2@ptr)
+			e1@pnt <- e1@pnt$union(e2@pnt)
 		} else if (oper == "*") {
-			e1@ptr <- e1@ptr$intersect(e2@ptr)
+			e1@pnt <- e1@pnt$intersect(e2@pnt)
 		} else if (oper == "-") {
-			e1@ptr <- e1@ptr$erase(e2@ptr)
+			e1@pnt <- e1@pnt$erase(e2@pnt)
 		} else {
 			error(oper, "only operators +, *, and - are supported for SpatVector")
 		}
@@ -123,7 +123,7 @@ setMethod("Arith", signature(e1="SpatRaster", e2="SpatRaster"),
     function(e1, e2){
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
-		e1@ptr <- e1@ptr$arith_rast(e2@ptr, oper, FALSE, opt)
+		e1@pnt <- e1@pnt$arith_rast(e2@pnt, oper, FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -133,7 +133,7 @@ setMethod("Arith", signature(e1="SpatRaster", e2="numeric"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_numb(e2, oper, FALSE, FALSE, opt)
+		e1@pnt <- e1@pnt$arith_numb(e2, oper, FALSE, FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -154,7 +154,7 @@ setMethod("Arith", signature(e1="numeric", e2="SpatRaster"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e2@ptr <- e2@ptr$arith_numb(e1, oper, TRUE, FALSE, opt)
+		e2@pnt <- e2@pnt$arith_numb(e1, oper, TRUE, FALSE, opt)
 		messages(e2, oper)
 	}
 )
@@ -169,7 +169,7 @@ setMethod("Arith", signature(e1="SpatRaster", e2="matrix"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_m(as.vector(e2), oper, dim(e2)[1:2], FALSE, opt)
+		e1@pnt <- e1@pnt$arith_m(as.vector(e2), oper, dim(e2)[1:2], FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -178,7 +178,7 @@ setMethod("Arith", signature(e1="matrix", e2="SpatRaster"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_m(as.vector(e2), oper, dim(e2)[1:2], TRUE, opt)
+		e1@pnt <- e1@pnt$arith_m(as.vector(e2), oper, dim(e2)[1:2], TRUE, opt)
 		messages(e1, oper)
 	}
 )
@@ -189,7 +189,7 @@ setMethod("Compare", signature(e1="SpatRaster", e2="SpatRaster"),
     function(e1, e2){
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
-		e1@ptr <- e1@ptr$arith_rast(e2@ptr, oper, FALSE, opt)
+		e1@pnt <- e1@pnt$arith_rast(e2@pnt, oper, FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -199,7 +199,7 @@ setMethod("Compare", signature(e1="SpatRaster", e2="numeric"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_numb(e2, oper, FALSE, FALSE, opt)
+		e1@pnt <- e1@pnt$arith_numb(e2, oper, FALSE, FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -209,7 +209,7 @@ setMethod("Compare", signature(e1="numeric", e2="SpatRaster"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e2@ptr <- e2@ptr$arith_numb(e1, oper, TRUE, FALSE, opt)
+		e2@pnt <- e2@pnt$arith_numb(e1, oper, TRUE, FALSE, opt)
 		messages(e2, oper)
 	}
 )
@@ -218,7 +218,7 @@ setMethod("Compare", signature(e1="SpatRaster", e2="matrix"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_m(as.vector(e2), oper, dim(e2)[1:2], FALSE, opt)
+		e1@pnt <- e1@pnt$arith_m(as.vector(e2), oper, dim(e2)[1:2], FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -227,7 +227,7 @@ setMethod("Compare", signature(e1="matrix", e2="SpatRaster"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_m(as.vector(e2), oper, dim(e2)[1:2], TRUE, opt)
+		e1@pnt <- e1@pnt$arith_m(as.vector(e2), oper, dim(e2)[1:2], TRUE, opt)
 		messages(e1, oper)
 	}
 )
@@ -262,7 +262,7 @@ setMethod("Compare", signature(e1="SpatRaster", e2="character"),
 			error(oper, "comparisons only supported for single values (see %in% and match)")
 		}
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$arith_numb(e2, oper, TRUE, FALSE, opt)
+		e1@pnt <- e1@pnt$arith_numb(e2, oper, TRUE, FALSE, opt)
 		messages(e1, oper)
 	}
 )
@@ -273,7 +273,7 @@ setMethod("Logic", signature(e1="SpatRaster", e2="SpatRaster"),
     function(e1, e2){
 		oper <- as.vector(.Generic)[1]
 		opt <- spatOptions()
-		e1@ptr <- e1@ptr$logic_rast(e2@ptr, oper, opt)
+		e1@pnt <- e1@pnt$logic_rast(e2@pnt, oper, opt)
 		messages(e1, oper)
 	}
 )
@@ -283,7 +283,7 @@ setMethod("Logic", signature(e1="SpatRaster", e2="numeric"),
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
 		e2 <- as.logical(e2)
-		e1@ptr <- e1@ptr$logic_numb(e2, oper, opt)
+		e1@pnt <- e1@pnt$logic_numb(e2, oper, opt)
 		messages(e1, oper)
 	}
 )
@@ -294,7 +294,7 @@ setMethod("Logic", signature(e1="numeric", e2="SpatRaster"),
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
 		e1 <- as.logical(e1)
-		e2@ptr <- e2@ptr$logic_numb(e1, oper, opt)
+		e2@pnt <- e2@pnt$logic_numb(e1, oper, opt)
 		messages(e2, oper)
 	}
 )
@@ -303,7 +303,7 @@ setMethod("Logic", signature(e1="SpatRaster", e2="logical"),
     function(e1, e2){
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
-		e1@ptr <- e1@ptr$logic_numb(e2, oper, opt)
+		e1@pnt <- e1@pnt$logic_numb(e2, oper, opt)
 		messages(e1, oper)
 	}
 )
@@ -313,7 +313,7 @@ setMethod("Logic", signature(e1="logical", e2="SpatRaster"),
     function(e1, e2){
 		opt <- spatOptions()
 		oper <- as.vector(.Generic)[1]
-		e2@ptr <- e2@ptr$logic_numb(e1, oper, opt)
+		e2@pnt <- e2@pnt$logic_numb(e1, oper, opt)
 		messages(e2, oper)
 	}
 )
@@ -328,7 +328,7 @@ setMethod("!", signature(x="SpatRaster"),
 setMethod("not.na", signature(x="SpatRaster"),
 	function(x, falseNA=FALSE, filename="", ...) {
 		opt <- spatOptions(filename=filename, ...)
-		x@ptr <- x@ptr$not_na(falseNA, opt)
+		x@pnt <- x@pnt$not_na(falseNA, opt)
 		messages(x, "not.na")
 	}
 )
@@ -337,7 +337,7 @@ setMethod("not.na", signature(x="SpatRaster"),
 setMethod("isTRUE", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$is_true(FALSE, opt)
+		x@pnt <- x@pnt$is_true(FALSE, opt)
 		messages(x, "isTRUE")
 	}
 )
@@ -346,7 +346,7 @@ setMethod("isTRUE", signature(x="SpatRaster"),
 setMethod("isFALSE", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$is_false(FALSE, opt)
+		x@pnt <- x@pnt$is_false(FALSE, opt)
 		messages(x, "isFALSE")
 	}
 )
@@ -360,12 +360,12 @@ setMethod("as.logical", signature(x="SpatRaster"),
 
 setMethod("is.bool", signature(x="SpatRaster"),
 	function(x) {
-		x@ptr$valueType(FALSE) == 3
+		x@pnt$valueType(FALSE) == 3
 	}
 )
 setMethod("is.int", signature(x="SpatRaster"),
 	function(x) {
-		x@ptr$valueType(FALSE) == 1
+		x@pnt$valueType(FALSE) == 1
 	}
 )
 
@@ -373,7 +373,7 @@ setMethod("is.int", signature(x="SpatRaster"),
 setMethod("as.bool", signature(x="SpatRaster"),
 	function(x, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@ptr <- x@ptr$is_true(FALSE, opt)
+		x@pnt <- x@pnt$is_true(FALSE, opt)
 		messages(x, "as.boolean")
 	}
 )
@@ -381,7 +381,7 @@ setMethod("as.bool", signature(x="SpatRaster"),
 setMethod("as.int", signature(x="SpatRaster"),
 	function(x, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@ptr <- x@ptr$math("trunc", opt)
+		x@pnt <- x@pnt$math("trunc", opt)
 		messages(x, "as.int")
 	}
 )
@@ -396,7 +396,7 @@ setMethod("as.integer", signature(x="SpatRaster"),
 setMethod("is.na", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$isnan(FALSE, opt)
+		x@pnt <- x@pnt$isnan(FALSE, opt)
 		messages(x, "is.na")
 	}
 )
@@ -406,9 +406,9 @@ setMethod("countNA", signature(x="SpatRaster"),
 		opt <- spatOptions()
 		n <- round(n)
 		if (n == 1) {
-			x@ptr <- x@ptr$anynan(FALSE, opt)
+			x@pnt <- x@pnt$anynan(FALSE, opt)
 		} else {
-			x@ptr <- x@ptr$countnan(n, opt)
+			x@pnt <- x@pnt$countnan(n, opt)
 		}
 		messages(x, "countNA")
 	}
@@ -418,7 +418,7 @@ setMethod("countNA", signature(x="SpatRaster"),
 setMethod("anyNA", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$anynan(FALSE, opt)
+		x@pnt <- x@pnt$anynan(FALSE, opt)
 		messages(x, "anyNA")
 	}
 )
@@ -426,7 +426,7 @@ setMethod("anyNA", signature(x="SpatRaster"),
 setMethod("noNA", signature(x="SpatRaster"),
 	function(x, falseNA=FALSE) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$nonan(falseNA, opt)
+		x@pnt <- x@pnt$nonan(falseNA, opt)
 		messages(x, "noNA")
 	}
 )
@@ -435,7 +435,7 @@ setMethod("noNA", signature(x="SpatRaster"),
 setMethod("allNA", signature(x="SpatRaster"),
 	function(x, falseNA=FALSE) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$allnan(falseNA, opt)
+		x@pnt <- x@pnt$allnan(falseNA, opt)
 		messages(x, "allNA")
 	}
 )
@@ -443,7 +443,7 @@ setMethod("allNA", signature(x="SpatRaster"),
 setMethod("is.nan", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$isnan(FALSE, opt)
+		x@pnt <- x@pnt$isnan(FALSE, opt)
 		messages(x, "is.nan")
 	}
 )
@@ -452,7 +452,7 @@ setMethod("is.nan", signature(x="SpatRaster"),
 setMethod("is.finite", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$isfinite(FALSE, opt)
+		x@pnt <- x@pnt$isfinite(FALSE, opt)
 		messages(x, "is.finite")
 	}
 )
@@ -460,7 +460,7 @@ setMethod("is.finite", signature(x="SpatRaster"),
 setMethod("is.infinite", signature(x="SpatRaster"),
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$isinfinite(FALSE, opt)
+		x@pnt <- x@pnt$isinfinite(FALSE, opt)
 		messages(x, "is.infinite")
 	}
 )
@@ -492,9 +492,9 @@ setMethod("is.infinite", signature(x="SpatRaster"),
 	opt <- spatOptions(filename, overwrite, wopt=wopt)
 	r <- rast()
 	if (is.null(add)) {
-		r@ptr <- x@ptr$summary(fun, na.rm, opt)
+		r@pnt <- x@pnt$summary(fun, na.rm, opt)
 	} else {
-		r@ptr <- x@ptr$summary_numb(fun, add, na.rm, opt)
+		r@pnt <- x@pnt$summary_numb(fun, add, na.rm, opt)
 	}
 	messages(r, fun)
 	r
@@ -504,7 +504,7 @@ setMethod("is.infinite", signature(x="SpatRaster"),
 setMethod("which.max", "SpatRaster",
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$summary("which.max", TRUE, opt)
+		x@pnt <- x@pnt$summary("which.max", TRUE, opt)
 		messages(x, "which.max")
 	}
 )
@@ -512,7 +512,7 @@ setMethod("which.max", "SpatRaster",
 setMethod("which.min", "SpatRaster",
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$summary("which.min", TRUE, opt)
+		x@pnt <- x@pnt$summary("which.min", TRUE, opt)
 		messages(x, "which.min")
 	}
 )
@@ -521,7 +521,7 @@ setMethod("which.min", "SpatRaster",
 setMethod("which.lyr", "SpatRaster",
 	function(x) {
 		opt <- spatOptions()
-		x@ptr <- x@ptr$summary("which", TRUE, opt)
+		x@pnt <- x@pnt$summary("which", TRUE, opt)
 		messages(x, "which.lyr")
 	}
 )
@@ -560,7 +560,7 @@ wherefun <- function(out, list, values) {
 setMethod("where.max", "SpatRaster",
 	function(x, values=TRUE, list=FALSE) {
 		opt <- spatOptions()
-		out <- x@ptr$where("max", values, opt)
+		out <- x@pnt$where("max", values, opt)
 		x <- messages(x, "where.max")
 		wherefun(out, list, values)
 	}
@@ -569,7 +569,7 @@ setMethod("where.max", "SpatRaster",
 setMethod("where.min", "SpatRaster",
 	function(x, values=TRUE, list=FALSE) {
 		opt <- spatOptions()
-		out <- x@ptr$where("min", values, opt)
+		out <- x@pnt$where("min", values, opt)
 		x <- messages(x, "where.min")
 		wherefun(out, list, values)
 	}
@@ -654,7 +654,7 @@ setMethod("Compare", signature(e1="SpatExtent", e2="SpatExtent"),
 		if (!(oper %in% c("==", "!=", ">", "<", ">=", "<="))) {
 			error(oper, "is not implemented for SpatExtent")
 		}
-		return( e1@ptr$compare(e2@ptr, oper, 0.000001) )
+		return( e1@pnt$compare(e2@pnt, oper, 0.000001) )
 	}
 )
 
@@ -691,7 +691,7 @@ setMethod("modal", signature("SpatRaster"),
 		if (is.null(add)) {
 			add <- c(.5)[0]
 		}
-		x@ptr <- x@ptr$modal(add, ties[1], na.rm[1], opt)
+		x@pnt <- x@pnt$modal(add, ties[1], na.rm[1], opt)
 		messages(x, "modal")
 	}
 )
@@ -710,9 +710,9 @@ setMethod("compare", signature(x="SpatRaster"),
 
 		opt <- spatOptions(filename, overwrite, ...)
 		if (inherits(y, "SpatRaster")) {
-			x@ptr <- x@ptr$arith_rast(y@ptr, oper, falseNA[1], opt)
+			x@pnt <- x@pnt$arith_rast(y@pnt, oper, falseNA[1], opt)
 		} else {
-			x@ptr <- x@ptr$arith_numb(y, oper, FALSE, falseNA[1], opt)
+			x@pnt <- x@pnt$arith_numb(y, oper, FALSE, falseNA[1], opt)
 		}
 		messages(x, oper)
 	}
@@ -733,25 +733,25 @@ setMethod("logic", signature(x="SpatRaster"),
 		falseNA <- as.logical(falseNA[1])
 		
 		if (oper == "is.infinite") {
-			x@ptr <- x@ptr$isinfinite(falseNA, opt)
+			x@pnt <- x@pnt$isinfinite(falseNA, opt)
 		} else if (oper == "is.finite") {
-			x@ptr <- x@ptr$isfinite(falseNA, opt)
+			x@pnt <- x@pnt$isfinite(falseNA, opt)
 		} else if (oper == "is.na") {
-			x@ptr <- x@ptr$isnan(falseNA, opt)
+			x@pnt <- x@pnt$isnan(falseNA, opt)
 		} else if (oper == "isTRUE") {
-			x@ptr <- x@ptr$is_true(falseNA, opt)
+			x@pnt <- x@pnt$is_true(falseNA, opt)
 		} else if (oper == "isFALSE") {
-			x@ptr <- x@ptr$is_false(falseNA, opt)
+			x@pnt <- x@pnt$is_false(falseNA, opt)
 		} else if (oper == "allNA") {
-			x@ptr <- x@ptr$allnan(falseNA, opt)
+			x@pnt <- x@pnt$allnan(falseNA, opt)
 		} else if (oper == "noNA") {
-			x@ptr <- x@ptr$nonan(falseNA, opt)
+			x@pnt <- x@pnt$nonan(falseNA, opt)
 		} else if (oper == "anyNA") {
-			x@ptr <- x@ptr$anynan(falseNA, opt)
+			x@pnt <- x@pnt$anynan(falseNA, opt)
 		} else if (oper == "anyNA") {
-			x@ptr <- x@ptr$anynan(falseNA, opt)
+			x@pnt <- x@pnt$anynan(falseNA, opt)
 		} else if (oper == "!") {
-			x@ptr <- x@ptr$arith_numb(0, "==", FALSE, falseNA[1], opt)
+			x@pnt <- x@pnt$arith_numb(0, "==", FALSE, falseNA[1], opt)
 		} else {
 			error("logic", "??")
 		}
