@@ -4,11 +4,10 @@
 # License GPL v3
 
 
-
 setMethod("buffer", signature(x="SpatRaster"),
 	function(x, width, background=0, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@ptr <- x@ptr$buffer(width, background, opt)
+		x@pnt <- x@pnt$buffer(width, background, opt)
 		messages(x, "buffer")
 	}
 )
@@ -21,15 +20,19 @@ setMethod("distance", signature(x="SpatRaster", y="missing"),
 		}
 		opt <- spatOptions(filename, ...)
 		target <- as.numeric(target[1])
+		keepNA <- FALSE
 		if (!is.null(exclude)) {
 			exclude <- as.numeric(exclude[1])
 			if ((is.na(exclude) && is.na(target)) || isTRUE(exclude == target)) {
 				error("distance", "'target' and 'exclude' must be different") 
 			}
+			if (is.na(exclude)) {
+				keepNA <- TRUE
+			}
 		} else {
 			exclude <- NA
 		}
-		x@ptr <- x@ptr$rastDistance(target, exclude, tolower(unit), TRUE, haversine, opt)
+		x@pnt <- x@pnt$rastDistance(target, exclude, keepNA, tolower(unit), TRUE, haversine, opt)
 		messages(x, "distance")
 	}
 )
@@ -39,7 +42,7 @@ setMethod("costDist", signature(x="SpatRaster"),
 	function(x, target=0, scale=1, maxiter=50, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		maxiter <- max(maxiter[1], 2)
-		x@ptr <- x@ptr$costDistance(target[1], scale[1], maxiter, FALSE, opt)
+		x@pnt <- x@pnt$costDistance(target[1], scale[1], maxiter, FALSE, opt)
 		messages(x, "costDist")
 	}
 )
@@ -49,10 +52,10 @@ setMethod("gridDist", signature(x="SpatRaster"),
 	function(x, target=0, scale=1, maxiter=50, filename="", ...) {
 		opt <- spatOptions(filename, ...)
 		if (is.na(target)) {
-			x@ptr <- x@ptr$gridDistance(scale[1]	, opt)
+			x@pnt <- x@pnt$gridDistance(scale[1]	, opt)
 		} else {
 			maxiter <- max(maxiter[1], 2)
-			x@ptr <- x@ptr$costDistance(target[1], scale[1], maxiter, TRUE, opt)
+			x@pnt <- x@pnt$costDistance(target[1], scale[1], maxiter, TRUE, opt)
 		}
 		messages(x, "gridDist")
 	}
@@ -64,9 +67,9 @@ setMethod("distance", signature(x="SpatRaster", y="SpatVector"),
 		opt <- spatOptions(filename, ...)
 		unit <- as.character(unit[1])
 		if (rasterize) {
-			x@ptr <- x@ptr$vectDistanceRasterize(y@ptr, NA, NA, unit, haversine, opt)
+			x@pnt <- x@pnt$vectDistanceRasterize(y@pnt, NA, NA, unit, haversine, opt)
 		} else {
-			x@ptr <- x@ptr$vectDistanceDirect(y@ptr, unit, haversine, opt)
+			x@pnt <- x@pnt$vectDistanceDirect(y@pnt, unit, haversine, opt)
 		}
 		messages(x, "distance")
 	}
@@ -108,10 +111,10 @@ setMethod("distance", signature(x="SpatVector", y="ANY"),
 		}
 
 		if (sequential) {
-			return( x@ptr$distance_self(sequential, unit))
+			return( x@pnt$distance_self(sequential, unit))
 		}
 		unit <- as.character(unit[1])
-		d <- x@ptr$distance_self(sequential, unit)
+		d <- x@pnt$distance_self(sequential, unit)
 		messages(x, "distance")
 		class(d) <- "dist"
 		attr(d, "Size") <- nrow(x)
@@ -131,7 +134,7 @@ setMethod("distance", signature(x="SpatVector", y="ANY"),
 setMethod("distance", signature(x="SpatVector", y="SpatVector"),
 	function(x, y, pairwise=FALSE, unit="m") {
 		unit <- as.character(unit[1])
-		d <- x@ptr$distance_other(y@ptr, pairwise, unit)
+		d <- x@pnt$distance_other(y@pnt, pairwise, unit)
 		messages(x, "distance")
 		if (!pairwise) {
 			d <- matrix(d, nrow=nrow(x), ncol=nrow(y), byrow=TRUE)
@@ -149,7 +152,7 @@ setMethod("distance", signature(x="matrix", y="matrix"),
 		stopifnot(ncol(x) == 2)
 		stopifnot(ncol(y) == 2)
 		v <- vect()
-		d <- v@ptr$point_distance(x[,1], x[,2], y[,1], y[,2], pairwise[1], 1, lonlat)
+		d <- v@pnt$point_distance(x[,1], x[,2], y[,1], y[,2], pairwise[1], 1, lonlat)
 		messages(v)
 		if (pairwise) {
 			d
@@ -176,7 +179,7 @@ setMethod("distance", signature(x="matrix", y="missing"),
 setMethod("direction", signature(x="SpatRaster"),
 	function(x, from=FALSE, degrees=FALSE, filename="", ...) {
 		opt <- spatOptions(filename, ...)
-		x@ptr <- x@ptr$rastDirection(from[1], degrees[1], NA, NA, opt)
+		x@pnt <- x@pnt$rastDirection(from[1], degrees[1], NA, NA, opt)
 		messages(x, "direction")
 	}
 )
