@@ -48,8 +48,8 @@ graticule <- function(lon=30, lat=30, crs="") {
 	}
 
 	g <- new("SpatGraticule")
-	g@ptr <- v@ptr
-	g@box <- e@ptr 
+	g@pnt <- v@pnt
+	g@box <- e@pnt 
 	g
 }
 
@@ -57,12 +57,12 @@ graticule <- function(lon=30, lat=30, crs="") {
 #setMethod("project", signature(x="SpatGraticule"),
 #	function(x, y) {
 #		v <- vect()
-#		v@ptr <- x@ptr
+#		v@pnt <- x@pnt
 #		v <- project(v, y)
-#		x@ptr <- v@ptr
-#		v@ptr <- x@box
+#		x@pnt <- v@pnt
+#		v@pnt <- x@box
 #		v <- project(v, y)
-#		x@box <- v@ptr
+#		x@box <- v@pnt
 #		x
 #	}
 #)
@@ -71,13 +71,13 @@ setMethod("crop", signature(x="SpatGraticule"),
 	function(x, y) {
 		v <- vect()
 
-		v@ptr <- x@ptr
+		v@pnt <- x@pnt
 		v <- crop(v, y)
-		x@ptr <- v@ptr
+		x@pnt <- v@pnt
 
-		v@ptr <- x@box
+		v@pnt <- x@box
 		v <- crop(v, y)
-		x@box <- v@ptr
+		x@box <- v@pnt
 		x
 	}
 )
@@ -86,15 +86,15 @@ setMethod("erase", signature(x="SpatGraticule", y="SpatVector"),
 	function(x, y) {
 		v <- vect()
 	
-		v@ptr <- x@ptr
+		v@pnt <- x@pnt
 		y <- project(y, v)
 
 		v <- erase(v, y)
-		x@ptr <- v@ptr
+		x@pnt <- v@pnt
 
-		v@ptr <- x@box
+		v@pnt <- x@box
 		v <- erase(v, y)
-		x@box <- v@ptr
+		x@box <- v@pnt
 		x
 	}
 )
@@ -133,7 +133,7 @@ grat_labels <- function(v, retro, atlon, atlat, labloc, cex, col, offlon, offlat
 			labs <- paste0(x$lat,"\u00B0")		
 		}	
 		if (!is.null(atlat)) {
-			atlat <- round(na.omit(atlat))
+			atlat <- round(stats::na.omit(atlat))
 			atlat <- atlat[(atlat > 0) & (atlat <= length(labs))] 
 			labs <- labs[atlat]
 		}
@@ -168,7 +168,7 @@ grat_labels <- function(v, retro, atlon, atlat, labloc, cex, col, offlon, offlat
 			labs <- paste0(x$lon,"\u00B0")		
 		}
 		if (!is.null(atlon)) {
-			atlon <- round(na.omit(atlon))
+			atlon <- round(stats::na.omit(atlon))
 			atlon <- atlon[(atlon > 0) & (atlon <= length(labs))] 
 			labs <- labs[atlon]
 		}
@@ -199,7 +199,7 @@ grat_labels <- function(v, retro, atlon, atlat, labloc, cex, col, offlon, offlat
 setMethod("plot", signature(x="SpatGraticule", y="missing"),
 	function(x, y, background=NULL, col="black", mar=NULL, labels=TRUE, retro=FALSE, lab.loc=c(1,1), lab.lon=NULL, lab.lat=NULL, lab.cex=.65, lab.col="black", off.lat=0.25, off.lon=0.25, box=FALSE, box.col="black", add=FALSE, ...) {
 		b <- vect()
-		b@ptr <- x@box
+		b@pnt <- x@box
 		if (!is.null(mar)) mar <- rep_len(mar, 4)
 		if (!is.null(background)) {
 			plot(b, col=background, border=NA, axes=FALSE, mar=mar, add=add)
@@ -209,7 +209,7 @@ setMethod("plot", signature(x="SpatGraticule", y="missing"),
 			}
 		}
 		v <- vect()
-		v@ptr <- x@ptr
+		v@pnt <- x@pnt
 		lines(v, col=col, ...)
 		if (box) {
 			lwd <- list(...)$lwd
@@ -224,7 +224,7 @@ setMethod("plot", signature(x="SpatGraticule", y="missing"),
 setMethod("lines", signature(x="SpatGraticule"),
 	function(x, ...) {
 		v <- vect()
-		v@ptr <- x@ptr
+		v@pnt <- x@pnt
 		lines(v, ...)
 	}
 )
