@@ -32,7 +32,7 @@ new_rast <- function(nrows=10, ncols=10, nlyrs=1, xmin=0, xmax=1, ymin=0, ymax=1
 	#check_proj4_datum(crs)
 
 	r <- methods::new("SpatRaster")
-	r@ptr <- SpatRaster$new(c(nrows, ncols, nlyrs), e, crs)
+	r@pnt <- SpatRaster$new(c(nrows, ncols, nlyrs), e, crs)
 	r <- messages(r, "rast")
 
 	if (!missing(resolution)) {
@@ -84,7 +84,7 @@ setMethod("rast", signature(x="list"),
 		}
 		opt <- spatOptions()
 		for (i in 2:length(x)) {
-			out@ptr$addSource(x[[i]]@ptr, warn, opt)
+			out@pnt$addSource(x[[i]]@pnt, warn, opt)
 		}
 		out <- messages(out, "rast")
 		lnms <- names(x)
@@ -187,13 +187,13 @@ setMethod("rast", signature(x="character"),
 		if (is.null(drivers)) drivers <- ""[0]
 		if (length(subds) == 0) subds = 0
 		if (is.character(subds)) {
-			#r@ptr <- SpatRaster$new(f, -1, subds, FALSE, 0[])
-			r@ptr <- SpatRaster$new(f, -1, subds, FALSE, drivers, opts, 0[])
+			#r@pnt <- SpatRaster$new(f, -1, subds, FALSE, 0[])
+			r@pnt <- SpatRaster$new(f, -1, subds, FALSE, drivers, opts, 0[])
 		} else {
-			r@ptr <- SpatRaster$new(f, subds-1, "", FALSE, drivers, opts, 0[])
+			r@pnt <- SpatRaster$new(f, subds-1, "", FALSE, drivers, opts, 0[])
 		}
 		r <- messages(r, "rast")
-		if (r@ptr$getMessage() == "ncdf extent") {
+		if (r@pnt$getMessage() == "ncdf extent") {
 			# could have used opts="IGNORE_XY_AXIS_NAME_CHECKS=YES"
 			test <- try(r <- .ncdf_extent(r, f), silent=TRUE)
 			if (inherits(test, "try-error")) {
@@ -237,11 +237,11 @@ multi <- function(x, subds=0, xyz=3:1, drivers=NULL, opts=NULL) {
 	subds <- subds[1]
 
 	if (is.character(subds)) {
-		r@ptr <- SpatRaster$new(f, -1, subds, TRUE, drivers, opts, xyz-1)
+		r@pnt <- SpatRaster$new(f, -1, subds, TRUE, drivers, opts, xyz-1)
 	} else {
-		r@ptr <- SpatRaster$new(f, subds-1, ""[0], TRUE, drivers, opts, xyz-1)
+		r@pnt <- SpatRaster$new(f, subds-1, ""[0], TRUE, drivers, opts, xyz-1)
 	}
-	if (r@ptr$getMessage() == "ncdf extent") {
+	if (r@pnt$getMessage() == "ncdf extent") {
 		test <- try(r <- .ncdf_extent(r), silent=TRUE)
 		if (inherits(test, "try-error")) {
 			warn("rast", "GDAL did not find an extent. Cells not equally spaced?")
@@ -263,7 +263,7 @@ setMethod("rast", signature(x="SpatRaster"),
 		if (inherits(nlyrs, "SpatRaster")) {
 			error("rast", "use 'c()' to combine SpatRasters")
 		}
-		x@ptr <- x@ptr$geometry(nlyrs, props, keeptime, keepunits)
+		x@pnt <- x@pnt$geometry(nlyrs, props, keeptime, keepunits)
 		x <- messages(x, "rast")
 		if (!missing(names)) {
 			if (length(names) == nlyr(x)) names(x) <- names
@@ -284,7 +284,7 @@ setMethod("rast", signature(x="SpatRasterDataset"),
 			x[1]
 		} else {
 			r <- methods::new("SpatRaster")
-			r@ptr <- x@ptr$collapse()
+			r@pnt <- x@pnt$collapse()
 			nms <- names(x)
 			if (any(nms != "")) {
 				names(r) <- paste(rep(nms, nlyr(x)), names(r), sep="_")
@@ -298,6 +298,9 @@ setMethod("rast", signature(x="SpatRasterDataset"),
 setMethod("rast", signature(x="array"),
 	function(x, crs="", extent=NULL) {
 		dims <- dim(x)
+		if (length(dims) < 3) {
+			error("rast,array", "cannot handle an array with less than 3 dimensions")
+		}
 		if (length(dims) > 3) {
 			if (length(dims) == 4) {
 				if (dims[4] == 1) {
@@ -316,7 +319,7 @@ setMethod("rast", signature(x="array"),
 			e <- c(0, dims[2], 0, dims[1])
 		}
 		crs <- character_crs(crs, "rast")
-		r@ptr <- SpatRaster$new(dims, e, crs)
+		r@pnt <- SpatRaster$new(dims, e, crs)
 		values(r) <- x
 		messages(r, "rast")
 	}
@@ -476,7 +479,7 @@ setMethod("rast", signature(x="stars_proxy"),
 setMethod("NAflag<-", signature(x="SpatRaster"),
 	function(x, value)  {
 		value <- as.numeric(value)
-		if (!(x@ptr$setNAflag(value))) {
+		if (!(x@pnt$setNAflag(value))) {
 			error("NAflag<-", "cannot set this value")
 		}
 		x
@@ -485,7 +488,7 @@ setMethod("NAflag<-", signature(x="SpatRaster"),
 
 setMethod("NAflag", signature(x="SpatRaster"),
 	function(x)  {
-		x@ptr$getNAflag()
+		x@pnt$getNAflag()
 	}
 )
 
