@@ -4,30 +4,30 @@
 # License GPL v3
 
 readAll <- function(x) {
-	ok <- x@ptr$readAll()
+	ok <- x@pnt$readAll()
 	x <- messages(x, "readAll")
 	invisible(ok)
 }
 
-setMethod("readStart", signature(x="SpatRaster"), 
+setMethod("readStart", signature(x="SpatRaster"),
 	function(x) {
-		success <- x@ptr$readStart()
+		success <- x@pnt$readStart()
 		messages(x, "readStart")
 		if (!success) error("readStart,SpatRaster", "cannot open file for reading")
 		invisible(success)
 	}
 )
 
-setMethod("readStart", signature(x="SpatRasterDataset"), 
+setMethod("readStart", signature(x="SpatRasterDataset"),
 	function(x) {
-		success <- x@ptr$readStart()
+		success <- x@pnt$readStart()
 		messages(x, "readStart")
 		if (!success) error("readStart,SpatRasterDataset", "cannot open file for reading")
 		invisible(success)
 	}
 )
 
-#setMethod("readStart", signature(x="SpatRasterDataset"), 
+#setMethod("readStart", signature(x="SpatRasterDataset"),
 #	function(x, ...) {
 #		nsd <- length(x)
 #		for (i in 1:nsd) {
@@ -41,17 +41,17 @@ setMethod("readStart", signature(x="SpatRasterDataset"),
 #)
 
 
-setMethod("readStop", signature(x="SpatRaster"), 
+setMethod("readStop", signature(x="SpatRaster"),
 	function(x) {
-		success <- x@ptr$readStop()
+		success <- x@pnt$readStop()
 		messages(x, "readStop")
 		invisible(success)
 	}
 )
 
-setMethod("readStop", signature(x="SpatRasterDataset"), 
+setMethod("readStop", signature(x="SpatRasterDataset"),
 	function(x) {
-		success <- x@ptr$readStop()
+		success <- x@pnt$readStop()
 		messages(x, "readStop")
 		invisible(success)
 	}
