@@ -396,12 +396,12 @@ sampleRaster <- function(x, size, method, replace, ext=NULL, warn) {
 	}
 	if (method == "regular") {
 		if (length(size) > 1) {
-			x@ptr <- x@ptr$sampleRowColRaster(size[1], size[2], warn[1])
+			x@pnt <- x@pnt$sampleRowColRaster(size[1], size[2], warn[1])
 		} else {
-			x@ptr <- x@ptr$sampleRegularRaster(size)
+			x@pnt <- x@pnt$sampleRegularRaster(size)
 		}
 	} else if (method == "random") {
-		x@ptr <- x@ptr$sampleRandomRaster(size, replace, .seed())
+		x@pnt <- x@pnt$sampleRandomRaster(size, replace, .seed())
 	} else {
 		error("spatSample", "method must be 'regular' or 'random' if as.raster=TRUE")
 	}
@@ -522,9 +522,9 @@ setMethod("spatSample", signature(x="SpatRaster"),
 		if (method == "regular") {
 			opt <- spatOptions()
 			if (length(size) > 1) {
-				v <- x@ptr$sampleRowColValues(size[1], size[2], opt)
+				v <- x@pnt$sampleRowColValues(size[1], size[2], opt)
 			} else {
-				v <- x@ptr$sampleRegularValues(size, opt)
+				v <- x@pnt$sampleRegularValues(size, opt)
 			}
 			x <- messages(x, "spatSample")
 			if (length(v) > 0) {
@@ -540,7 +540,7 @@ setMethod("spatSample", signature(x="SpatRaster"),
 				cnrs <- .sampleCellsExhaustive(x, size, replace, ext, weights=NULL, warn=FALSE)
 				out <- x[cnrs]	
 			} else {
-				#v <- x@ptr$sampleRandomValues(size, replace, seed)
+				#v <- x@pnt$sampleRandomValues(size, replace, seed)
 				if (size > 0.75 * ncell(x)) {
 					if (na.rm) {
 						out <- stats::na.omit(values(x))
@@ -606,9 +606,9 @@ setMethod("spatSample", signature(x="SpatExtent"),
 		size <- round(size)
 		stopifnot(size > 0)
 		if (method=="random") {
-			s <- x@ptr$sampleRandom(size, lonlat, .seed())
+			s <- x@pnt$sampleRandom(size, lonlat, .seed())
 		} else {
-			s <- x@ptr$sampleRegular(size, lonlat)
+			s <- x@pnt$sampleRegular(size, lonlat)
 		}
 		s <- do.call(cbind, s)
 		colnames(s) <- c("x", "y")
@@ -676,7 +676,7 @@ setMethod("spatSample", signature(x="SpatExtent"),
 
 
 #coordinates <- function(x) {
-#	do.call(cbind, x@ptr$coordinates())
+#	do.call(cbind, x@pnt$coordinates())
 #}
 
 get_field_name <- function(x, nms, sender="") {
@@ -730,9 +730,9 @@ setMethod("spatSample", signature(x="SpatVector"),
 			}
 			out <- vect()
 			if (length(size) == 1) {
-				out@ptr <- x@ptr$sample(size, method[1], .seed())
+				out@pnt <- x@pnt$sample(size, method[1], .seed())
 			} else {
-				out@ptr <- x@ptr$sampleGeom(size, method[1], .seed())	
+				out@pnt <- x@pnt$sampleGeom(size, method[1], .seed())	
 			}
 			messages(x, "spatSample")
 			return(messages(out, "spatSample"))
