@@ -17,7 +17,7 @@ function(x, index, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())
 			if (is.na(i)) {
 				error("tapp", paste("invalid time step. Use one of:", paste(choices, collapse=", ")))
 			}
-			if (!x@ptr$hasTime) {
+			if (!x@pnt$hasTime) {
 				error("tapp", "x has no time data")
 			}
 			choice <- choices[i]
@@ -93,7 +93,7 @@ function(x, index, fun, ..., cores=1, filename="", overwrite=FALSE, wopt=list())
 		if (txtfun %in% .cpp_funs) {
 			opt <- spatOptions(filename, overwrite, wopt=wopt)
 			narm <- isTRUE(list(...)$na.rm)
-			x@ptr <- x@ptr$apply(index, txtfun, narm, nms, out_time, out_tstep, out_tz, opt)
+			x@pnt <- x@pnt$apply(index, txtfun, narm, nms, out_time, out_tstep, out_tz, opt)
 			return(messages(x, "tapp"))
 		}
 	}
