@@ -5,7 +5,7 @@
 
 setMethod("hasValues", signature(x="SpatRaster"),
 	function(x) {
-		x@ptr$hasValues
+		x@pnt$hasValues
 	}
 )
 
@@ -44,8 +44,8 @@ setMethod("hasValues", signature(x="SpatRaster"),
 	}
 	dd <- !(bb | ii | ff)
 	if (any(dd)) {
-		d = which(dd)
-		v[,d] = replace(v[,d], is.na(v[,d]), NA)
+		d <- which(dd)
+		v[,d] <- replace(v[,d], is.na(v[,d]), NA)
 	}
 	v
 }
@@ -55,7 +55,7 @@ setMethod("readValues", signature(x="SpatRaster"),
 function(x, row=1, nrows=nrow(x), col=1, ncols=ncol(x), mat=FALSE, dataframe=FALSE, ...) {
 	stopifnot(row > 0 && nrows > 0)
 	stopifnot(col > 0 && ncols > 0)
-	v <- x@ptr$readValues(row-1, nrows, col-1, ncols)
+	v <- x@pnt$readValues(row-1, nrows, col-1, ncols)
 	messages(x, "readValues")
 	if (dataframe) {
 		v <- matrix(v, ncol = nlyr(x))
@@ -115,7 +115,7 @@ setMethod("focalValues", signature("SpatRaster"),
 		readStart(x)
 		on.exit(readStop(x))
 		opt <- spatOptions()
-		m <- matrix(x@ptr$focalValues(w, fill, max(0, row-1), nrows, opt), ncol=prod(w), byrow=TRUE)
+		m <- matrix(x@pnt$focalValues(w, fill, max(0, row-1), nrows, opt), ncol=prod(w), byrow=TRUE)
 		messages(x, "focalValues")
 		m
 	}
@@ -205,7 +205,7 @@ setMethod("setValues", signature("SpatRaster"),
 		opt <- spatOptions()
 
 		if (lv == 1) {
-			y@ptr$setValues(values, opt)
+			y@pnt$setValues(values, opt)
 		} else {
 			if (lv > (nc * nl)) {
 				warn("setValues", "values is larger than the size of cells")
@@ -214,7 +214,7 @@ setMethod("setValues", signature("SpatRaster"),
 				warn("setValues", "values were recycled")
 				values <- rep(values, length.out=nc*nl)
 			}
-			y@ptr$setValues(values, opt)
+			y@pnt$setValues(values, opt)
 		}
 		y <- messages(y, "setValues")
 		if (make_factor) {
@@ -227,9 +227,9 @@ setMethod("setValues", signature("SpatRaster"),
 		if (set_coltab) {
 			coltab(y) <- fv
 		} else if (is.logical(values)) {
-			if (!all(is.na(values))) y@ptr$setValueType(3)
+			if (!all(is.na(values))) y@pnt$setValueType(3)
 		} else if (is.integer(values)) {
-			y@ptr$setValueType(1)
+			y@pnt$setValueType(1)
 		}
 		y
 	}
@@ -239,7 +239,7 @@ setMethod("setValues", signature("SpatRaster"),
 
 setMethod("inMemory", signature(x="SpatRaster"),
 	function(x, bylayer=FALSE) {
-		r <- x@ptr$inMemory
+		r <- x@pnt$inMemory
 		if (bylayer) {
 			nl <- .nlyrBySource(x)
 			r <- rep(r, nl)
@@ -249,30 +249,30 @@ setMethod("inMemory", signature(x="SpatRaster"),
 )
 
 
-#..hasValues <- function(x) { x@ptr$hasValues}
-#..inMemory <- function(x) { x@ptr$inMemory }
-#..filenames <- function(x) {	x@ptr$filenames }
+#..hasValues <- function(x) { x@pnt$hasValues}
+#..inMemory <- function(x) { x@pnt$inMemory }
+#..filenames <- function(x) {	x@pnt$filenames }
 
 subsetSource <- function(x, i) {
-	x@ptr <- x@ptr$subsetSource(i-1)
+	x@pnt <- x@pnt$subsetSource(i-1)
 	messages(x)
 }
 
 setMethod("sources", signature(x="SpatRaster"),
 	function(x, nlyr=FALSE, bands=FALSE) {
-		src <- x@ptr$filenames()
+		src <- x@pnt$filenames()
 		Encoding(src) <- "UTF-8"
 		if (bands) {
-			nls <- x@ptr$nlyrBySource()
+			nls <- x@pnt$nlyrBySource()
 			d <- data.frame(sid=rep(1:length(src), nls),
 						 source=rep(src, nls),
-						 bands=x@ptr$getBands()+1, stringsAsFactors=FALSE)
+						 bands=x@pnt$getBands()+1, stringsAsFactors=FALSE)
 			if (nlyr) {
 				d$nlyr <- rep(nls, nls)
 			}
 			d
 		} else if (nlyr) {
-			data.frame(source=src, nlyr=x@ptr$nlyrBySource(), stringsAsFactors=FALSE)
+			data.frame(source=src, nlyr=x@pnt$nlyrBySource(), stringsAsFactors=FALSE)
 		} else {
 			src
 		}
@@ -298,7 +298,7 @@ setMethod("sources", signature(x="SpatRasterDataset"),
 			x <- lapply(1:length(x), function(i) cbind(cid=i, x[[i]]))
 			do.call(rbind, x)
 		} else {
-			x@ptr$filenames()
+			x@pnt$filenames()
 		}
 	}
 )
@@ -306,11 +306,11 @@ setMethod("sources", signature(x="SpatRasterDataset"),
 
 setMethod("sources", signature(x="SpatVector"),
 	function(x) {
-		if (x@ptr$source != "") {
-			if (x@ptr$layer != tools::file_path_sans_ext(basename(x@ptr$source))) {
-				paste0(x@ptr$source, "::", x@ptr$layer)
+		if (x@pnt$source != "") {
+			if (x@pnt$layer != tools::file_path_sans_ext(basename(x@pnt$source))) {
+				paste0(x@pnt$source, "::", x@pnt$layer)
 			} else {
-				x@ptr$source
+				x@pnt$source
 			}
 		} else {
 			""
@@ -320,32 +320,32 @@ setMethod("sources", signature(x="SpatVector"),
 
 setMethod("sources", signature(x="SpatVectorProxy"),
 	function(x) {
-		if (x@ptr$v$layer != tools::file_path_sans_ext(basename(x@ptr$v$source))) {
-			paste0(x@ptr$v$source, "::", x@ptr$v$layer)
+		if (x@pnt$v$layer != tools::file_path_sans_ext(basename(x@pnt$v$source))) {
+			paste0(x@pnt$v$source, "::", x@pnt$v$layer)
 		} else {
-			x@ptr$v$source
+			x@pnt$v$source
 		}
 	}
 )
 
 setMethod("hasMinMax", signature(x="SpatRaster"),
 	function(x) {
-		x@ptr$hasRange
+		x@pnt$hasRange
 	}
 )
 
 setMethod("minmax", signature(x="SpatRaster"),
 	function(x, compute=FALSE) {
-		have <- x@ptr$hasRange
+		have <- x@pnt$hasRange
 		if (!all(have)) {
 			if (compute) {
 				opt <- spatOptions()
-				x@ptr$setRange(opt, FALSE)
+				x@pnt$setRange(opt, FALSE)
 			} else {
 				warn("minmax", "min and max values not available for all layers. See 'setMinMax' or 'global'")
 			}
 		}
-		r <- rbind(x@ptr$range_min, x@ptr$range_max)
+		r <- rbind(x@pnt$range_min, x@pnt$range_max)
 		if (!compute) {
 			r[,!have] <- c(Inf, -Inf)
 		}
@@ -360,28 +360,29 @@ setMethod("setMinMax", signature(x="SpatRaster"),
 	function(x, force=FALSE) {
 		opt <- spatOptions()
 		if (force) {
-			x@ptr$setRange(opt, TRUE)
+			x@pnt$setRange(opt, TRUE)
 		} else if (!all(hasMinMax(x))) {
-			x@ptr$setRange(opt, FALSE)
+			x@pnt$setRange(opt, FALSE)
 		}
 		x <- messages(x, "setMinMax")
 	}
 )
 
 
+
 setMethod("compareGeom", signature(x="SpatRaster", y="SpatRaster"),
 	function(x, y, ..., lyrs=FALSE, crs=TRUE, warncrs=FALSE, ext=TRUE, rowcol=TRUE, res=FALSE, stopOnError=TRUE, messages=FALSE) {
 		opt <- spatOptions("")
-		out <- x@ptr$compare_geom(y@ptr, lyrs, crs, opt$tolerance, warncrs, ext, rowcol, res)
+		out <- x@pnt$compare_geom(y@pnt, lyrs, crs, opt$tolerance, warncrs, ext, rowcol, res)
 		if (stopOnError) {
 			messages(x, "compareGeom")
 		} else {
 			m <- NULL
-			if (x@ptr$has_warning()) {
-				m <- x@ptr$getWarnings()
+			if (x@pnt$has_warning()) {
+				m <- x@pnt$getWarnings()
 			}
-			if (x@ptr$has_error()) {
-				m <- c(m, x@ptr$getError())
+			if (x@pnt$has_error()) {
+				m <- c(m, x@pnt$getError())
 			}
 			if (!is.null(m) && messages) {
 				message(paste(m, collapse="\n"))
@@ -393,9 +394,8 @@ setMethod("compareGeom", signature(x="SpatRaster", y="SpatRaster"),
 				if (!inherits(dots[[i]], "SpatRaster")) {
 					error("compareGeom", "all additional arguments must be a SpatRaster")
 				}
-				bool <- x@ptr$compare_geom(dots[[i]]@ptr, lyrs, crs, opt$tolerance, warncrs, ext, rowcol, res)
-				if (stopOnError) messages(x, "compareGeom")
-				res <- bool & out
+				out <- out & 
+					compareGeom(x, dots[[i]], lyrs=lyrs, crs=crs, warncrs=warncrs, ext=ext, rowcol=rowcol, res=res, stopOnError=stopOnError, messages=messages)
 			}
 		}
 		out
@@ -403,10 +403,63 @@ setMethod("compareGeom", signature(x="SpatRaster", y="SpatRaster"),
 )
 
 
+setMethod("compareGeom", signature(x="SpatRaster", y="list"),
+	function(x, y, ..., lyrs=FALSE, crs=TRUE, warncrs=FALSE, ext=TRUE, rowcol=TRUE, res=FALSE, stopOnError=TRUE, messages=FALSE) {
+		dots <- list(...)
+		if (length(dots) > 0) {
+			y <- c(y, dots)
+		}
+		isr <- sapply(y, inherits, "SpatRaster")
+		if (!all(isr)) {
+			y <- y[isr]
+			if (length(y) == 0) error("compareGeom", "none of the elements of y is a SpatRaster")
+			n <- sum(!isr)
+			if (n > 1) {
+				warn("compareGeom", paste(n, "elements of y are not a SpatRaster"))
+			} else {
+				warn("compareGeom", paste("1 element of y is not a SpatRaster"))
+			}
+		}
+		out <- sapply(y, compareGeom, y=x, lyrs=lyrs, crs=crs, warncrs=warncrs, ext=ext, rowcol=rowcol, res=res, stopOnError=stopOnError, messages=messages)
+		if (!all(isr)) {
+			res <- rep(NA, length(isr))
+			res[isr] <- out
+			return(res)
+		}
+		all(out)
+	}
+)
+
+
+setMethod("compareGeom", signature(x="SpatRasterCollection", y="missing"),
+	function(x, y, ..., lyrs=FALSE, crs=TRUE, warncrs=FALSE, ext=TRUE, rowcol=TRUE, res=FALSE, stopOnError=FALSE, messages=FALSE) {
+		x <- as.list(x)
+		dots <- list(...)
+		if (length(dots) > 0) {
+			error("compareGeom", "when x is a SpatRasterCollection, additional arguments are ignored")
+		}
+		if (length(x) == 1) return(TRUE)
+		out <- sapply(x[-1], compareGeom, y=x[1], lyrs=lyrs, crs=crs, warncrs=warncrs, ext=ext, rowcol=rowcol, res=res, stopOnError=stopOnError, messages=messages)
+		out
+	}
+)
+
+
+setMethod("compareGeom", signature(x="SpatRaster", y="SpatRasterCollection"),
+	function(x, y, ..., lyrs=FALSE, crs=TRUE, warncrs=FALSE, ext=TRUE, rowcol=TRUE, res=FALSE, stopOnError=FALSE, messages=FALSE) {
+		dots <- list(...)
+		if (length(dots) > 0) {
+			error("compareGeom", "when y is a SpatRasterCollection, additional arguments are ignored")
+		}
+		out <- sapply(as.list(y), compareGeom, y=x, lyrs=lyrs, crs=crs, warncrs=warncrs, ext=ext, rowcol=rowcol, res=res, stopOnError=stopOnError, messages=messages)
+		all(out)
+	}
+)
+
 
 setMethod("compareGeom", signature(x="SpatVector", y="SpatVector"),
 	function(x, y, tolerance=0) {
-		out <- x@ptr$equals_between(y@ptr, tolerance)
+		out <- x@pnt$equals_between(y@pnt, tolerance)
 		x <- messages(x, "compareGeom")
 		out[out == 2] <- NA
 		matrix(as.logical(out), nrow=nrow(x), byrow=TRUE)
@@ -415,7 +468,7 @@ setMethod("compareGeom", signature(x="SpatVector", y="SpatVector"),
 
 setMethod("compareGeom", signature(x="SpatVector", y="SpatVector"),
 	function(x, y, tolerance=0) {
-		out <- x@ptr$equals_within(tolerance)
+		out <- x@pnt$equals_within(tolerance)
 		x <- messages(x, "compareGeom")
 		out[out == 2] <- NA
 		out <- matrix(as.logical(out), nrow=nrow(x), byrow=TRUE)
@@ -431,8 +484,9 @@ setMethod("all.equal", signature(target="SpatRaster", current="SpatRaster"),
 			hvT <- hasValues(target)
 			hvC <- hasValues(current)
 			if (hvT && hvC) {
-				s <- spatSample(c(target, current), maxcell, "regular")
-				a <- all.equal(s[,1], s[,2], ...)
+				s1 <- spatSample(current, maxcell, "regular")
+				s2 <- spatSample(target, maxcell, "regular")
+				a <- all.equal(s1, s2, ...)
 			} else if (hvT || hvC) {
 				if (hvT) {
 					a <- "target has cell values, current does not"
@@ -456,13 +510,13 @@ setMethod("values", signature("SpatVector"),
 
 setMethod("values<-", signature("SpatVector", "data.frame"),
 	function(x, value) {
-		x@ptr <- x@ptr$deepcopy()
+		x@pnt <- x@pnt$deepcopy()
 		if (ncol(value) == 0) {
-			x@ptr$remove_df()
+			x@pnt$remove_df()
 			return(x)
 		}
 		value <- .makeSpatDF(value)
-		x@ptr$set_df(value)
+		x@pnt$set_df(value)
 		messages(x)
 	}
 )
@@ -489,15 +543,15 @@ setMethod("values<-", signature("SpatVector", "ANY"),
 
 setMethod("values<-", signature("SpatVector", "NULL"),
 	function(x, value) {
-		x@ptr <- x@ptr$deepcopy()
-		x@ptr$remove_df()
+		x@pnt <- x@pnt$deepcopy()
+		x@pnt$remove_df()
 		x
 	}
 )
 
 setMethod("setValues", signature("SpatVector"),
 	function(x, values) {
-		x@ptr <- x@ptr$deepcopy()
+		x@pnt <- x@pnt$deepcopy()
 		`values<-`(x, values)
 	}
 )
