@@ -21,7 +21,29 @@
 #include <chrono>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <filesystem>
+
+/*
+#if defined __has_include
+#	if __has_include (<filesystem>)
+# 		include <filesystem>
+		namespace filesyst = std::filesystem;
+#	else
+#		include <experimental/filesystem>
+		namespace filesyst = std::experimental::filesystem;
+#	endif
+#elif defined __GNUC__
+#	if __GNUC__ < 8
+#		include <experimental/filesystem>
+		namespace filesyst = std::experimental::filesystem;
+#	else 
+# 		include <filesystem>
+		namespace filesyst = std::filesystem;	
+#	endif
+#else 
+#	include <filesystem>
+    namespace filesyst = std::filesystem;
+#endif
+*/
 
 bool write_text(std::string filename, std::vector<std::string> s) {
 	std::ofstream f;
@@ -113,16 +135,16 @@ bool file_exists(const std::string& name) {
 
 bool path_exists(std::string path) {
 
-	std::filesystem::path filepath = path;
-	return std::filesystem::exists(path);
-
-//	std::filesystem::exists( const std::filesystem::path& p
-//	struct stat info;
-//	stat(path.c_str(), &info);
-//	if (info.st_mode & S_IFDIR) {
-//		return true;
-//	}
-//	return false;
+/*
+	filesyst::path filepath = path;
+	return filesyst::exists(filepath);
+*/
+	struct stat info;
+	stat(path.c_str(), &info);
+	if (info.st_mode & S_IFDIR) {
+		return true;
+	}
+	return false;
 }
 
 
