@@ -1,4 +1,4 @@
-// Copyright (c) 2018-2022  Robert J. Hijmans
+// Copyright (c) 2018-2023  Robert J. Hijmans
 //
 // This file is part of the "spat" library.
 //
@@ -25,6 +25,7 @@
 #include "spatBase.h"
 #include "spatTime.h"
 #include "spatFactor.h"
+#include <limits>
 
 class SpatDataFrame {
 	public:
@@ -44,13 +45,15 @@ class SpatDataFrame {
 		std::vector<std::string> names;
 		std::vector<unsigned> itype; //0 double, 1 long, 2 string, 3 bool, 4 time, 5 factor
 		std::vector<unsigned> iplace;
-		std::vector< std::vector<double>> dv;
-		std::vector< std::vector<long>> iv;
-		std::vector< std::vector<std::string>> sv;
-		std::vector< std::vector<int8_t>> bv;
-		std::vector< SpatTime_v> tv;
-		std::vector< SpatFactor> fv;		
+		std::vector<std::vector<double>> dv;
+		std::vector<std::vector<long>> iv;
+		std::vector<std::vector<std::string>> sv;
+		std::vector<std::vector<int8_t>> bv;
+		std::vector<SpatTime_v> tv;
+		std::vector<SpatFactor> fv;		
 		std::string NAS = "____NA_+";
+		long NAL = std::numeric_limits<long>::min();
+		SpatTime_t NAT = std::numeric_limits<SpatTime_t>::min();
 		
 		unsigned nrow();
 		unsigned ncol();
@@ -134,6 +137,8 @@ class SpatDataFrame {
 		std::vector<std::string> one_string();
 		SpatDataFrame unique();
 		size_t strwidth(unsigned i);
+
+		SpatDataFrame sortby(std::string field, bool descending);
 };
 
 #endif //SPATDATAFRAME_GUARD
